pycocoa.deprecated

Package pycocoa :: Module deprecated |
[frames] | no frames]

# Module deprecated

Deprecated classes, constants, functions, internals, etc.

Version: 25.03.16

Classes
| BuiltInScreen DEPRECATED on 2025.03.16, use `Screens.BuiltIn`.
| Cache2 DEPRECATED on 2025.02.15, to be removed.
| DeepestScreen DEPRECATED on 2025.03.16, use `Screens.Deepest`.
| ExternalScreen DEPRECATED on 2025.03.16, use `Screens.External`.
| MainScreen DEPRECATED on 2025.03.16, use `Screens.Main`.
| module_property_RO DEPRECATED on 2025.02.09, use `proxy_RO`.

Functions
fontfamilies(*prefixes) DEPRECATED on 25.03.13, use `fontFamilies`. |
fontnamesof(family) DEPRECATED on 25.03.13, use `fontNamesOf`. |
fontsof(family, **size_weight) DEPRECATED on 25.03.13, use `fontsOf`. |
fontsof4(family) DEPRECATED on 25.03.13, use `fontsOf4`. |
get_libPC() DEPRECATED on 25.02.25, use `Libs.PrintCore`. |
get_libs() DEPRECATED on 25.02.25, use `Libs`. |
property2(inst, name) DEPRECATED on 25.02.16, to be removed. |
sortuples(iterable) DEPRECATED on 25.02.09, to be removed. |

Variables
| __all__ = `_ALL_LAZY.deprecated`
| libAppKit = `<CDLL 'AppKit.framework/AppKit', handle 7fffa23edf`...`` DEPRECATED on 2025.02.25, use `Libs.AppKit`
| libCF = `<CDLL 'CoreFoundation.framework/CoreFoundation', handl`...`` DEPRECATED on 2025.02.25, use `Libs.CoreFoundation`
| libCG = `<CDLL 'CoreGraphics.framework/CoreGraphics', handle 7f`...`` DEPRECATED on 2025.02.25, use `Libs.CoreGraphics`
| libCT = `<CDLL 'CoreText.framework/CoreText', handle 7fffa23ee4`...`` DEPRECATED on 2025.02.25, use `Libs.CoreText`
| libFoundation = `<CDLL 'Foundation.framework/Foundation', handl`...`` DEPRECATED on 2025.02.25, use `Libs.Foundation`
| libobjc = `<CDLL 'libobjc.dylib', handle 7fffa23e3c6c at 7f8138`...`` DEPRECATED on 2025.02.25, use `Libs.ObjC`
| libPC = `<CDLL '/System/Library/Frameworks/ApplicationServices.`...`` DEPRECATED on 2025.02.25, use `Libs.PrintCore`
| OBJC_ASSOCIATION_ASSIGN = `0` DEPRECATED on 2025.02.20, use `OBJC_ASSOCIATION.ASSIGN`.
| OBJC_ASSOCIATION_COPY = `771` DEPRECATED on 2025.02.20, use `OBJC_ASSOCIATION.COPY`.
| OBJC_ASSOCIATION_COPY_NONATOMIC = `3` DEPRECATED on 2025.02.20, use `OBJC_ASSOCIATION.COPY_NONATOMIC`.
| OBJC_ASSOCIATION_RETAIN = `769` DEPRECATED on 2025.02.20, use `OBJC_ASSOCIATION.RETAIN`.
| OBJC_ASSOCIATION_RETAIN_NONATOMIC = `1` DEPRECATED on 2025.02.20, use `OBJC_ASSOCIATION.RETAIN_NONATOMIC`.

Variables Details

  ### libAppKit DEPRECATED on 2025.02.25, use `Libs.AppKit` Value:
      <CDLL 'AppKit.framework/AppKit', handle 7fffa23edf68 at 7f81385a5d50>

  ### libCF DEPRECATED on 2025.02.25, use `Libs.CoreFoundation` Value:
      <CDLL 'CoreFoundation.framework/CoreFoundation', handle 7fffa23e03a0 a
      t 7f81385a5590>

  ### libCG DEPRECATED on 2025.02.25, use `Libs.CoreGraphics` Value:
      <CDLL 'CoreGraphics.framework/CoreGraphics', handle 7fffa23ea520 at 7f
      81385a5f10>

  ### libCT DEPRECATED on 2025.02.25, use `Libs.CoreText` Value:
      <CDLL 'CoreText.framework/CoreText', handle 7fffa23ee430 at 7f8138431e
      90>

  ### libFoundation DEPRECATED on 2025.02.25, use `Libs.Foundation` Value:
      <CDLL 'Foundation.framework/Foundation', handle 7fffa23ef9a8 at 7f8138
      442390>

  ### libobjc DEPRECATED on 2025.02.25, use `Libs.ObjC` Value:
      <CDLL 'libobjc.dylib', handle 7fffa23e3c6c at 7f8138442650>

  ### libPC DEPRECATED on 2025.02.25, use `Libs.PrintCore` Value:
      <CDLL '/System/Library/Frameworks/ApplicationServices.framework/Framew
      orks/PrintCore.framework/PrintCore', handle 7fffa23cfd38 at 7f813864c2
      d0>